# <img src="assets/logomark.png" style="width: 40px;" alt="Logomark"> &nbsp; pysynthbio

`pysynthbio` is an Python package that provides a convenient interface to the [Synthesize Bio](https://www.synthesize.bio/) API, allowing users to generate realistic gene expression data based on specified biological conditions. This package enables researchers to easily access AI-generated transcriptomic data for various modalities including bulk RNA-seq and single-cell RNA-seq.

If you'd prefer 1-click dataset generation and analysis, try our [web platform](https://app.synthesize.bio/datasets/).

## Prerequisites

Create a [Synthesize Bio](https://app.synthesize.bio/) account and generate an [API Key](https://app.synthesize.bio/account/api-key).

## Installation

```
pip install pysynthbio
```

## Usage

[Quick start](https://synthesizebio.github.io/pysynthbio/usage/quickstart.html)

[Full documentation](https://synthesizebio.github.io/pysynthbio/)

## Questions? Suggestions? Support?

Email us at [support@synthesize.bio](mailto:support@synthesize.bio). We'd love to hear from you!